==> hyades.source_1.3.0_20040422_2239.zip: org/eclipse/hyades/uml2sd/trace/loaders/NodeInteractions.java <==
/**********************************************************************
 * Copyright (c) 2004 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.uml2sd.trace.loaders;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.hyades.models.hierarchy.TRCNode;
import org.eclipse.hyades.models.trace.TRCFullMethodInvocation;
import org.eclipse.hyades.uml2sd.trace.TraceSDPlugin;
import org.eclipse.hyades.uml2sd.trace.loaders.internal.TraceInteractionUtils;
import org.eclipse.hyades.uml2sd.ui.core.LifelineCategories;
import org.eclipse.hyades.uml2sd.ui.drawings.impl.ImageImpl;

/**
 * This class aims to populate a Node (host) Interaction UML2 Sequence Diagram.
 */
public class NodeInteractions extends NoMessageInteractions {
	
	/**
	 * Categories:
	 * - only one for nodes
	 */
	public static final int CATEGORY_NODE = 0;
	private static LifelineCategories[] traceCategories;
	static {
		traceCategories = new LifelineCategories[1];
		traceCategories[CATEGORY_NODE] = new LifelineCategories();
		traceCategories[CATEGORY_NODE].setName(TraceSDPlugin.getResourceString("STR_NODE")); //$NON-NLS-1$
		traceCategories[CATEGORY_NODE].setImage(new ImageImpl(TraceSDPlugin.getResourceImage("node_obj.gif"))); //$NON-NLS-1$
	}
	
	/**
	 * @return
	 */
	protected void createFrame() {
		super.createFrame();
		frame.setLifelineCategories(traceCategories);
	}

	/**
	 * @see org.eclipse.hyades.uml2sd.trace.loaders.BaseTraceInteractions#setFrameName()
	 */
	public void setFrameName() {
		frame.setName(TraceSDPlugin.getResourceString("STR_UML2SD_NODE_INTERACTION")); //$NON-NLS-1$
	}
	
	/**
	 * @see org.eclipse.hyades.uml2sd.trace.loaders.BaseTraceInteractions#getLifelineEObjectFromMethodInvocation(org.eclipse.hyades.models.trace.TRCFullMethodInvocation)
	 */
	protected EObject getLifelineEObjectFromMethodInvocation(
			TRCFullMethodInvocation mi) {
		return mi.getProcess().getAgent().getAgentProxy().getProcessProxy().getNode(); // TRCNode
	}
	
	/**
	 * @see org.eclipse.hyades.uml2sd.trace.loaders.BaseTraceInteractions#getLifeLineCategory(org.eclipse.emf.ecore.EObject)
	 */
	protected int getLifeLineCategory(EObject to) {
		return CATEGORY_NODE;
	}
	
	/**
	 * @see org.eclipse.hyades.uml2sd.trace.loaders.BaseTraceInteractions#getLifeLineTitle(org.eclipse.emf.ecore.EObject, boolean)
	 */
	protected String getLifeLineTitle(EObject to, boolean long_) {
		TRCNode node = (TRCNode)to;
		return node.getName(); //$NON-NLS-1$
	}

	/**
	 * @see org.eclipse.hyades.uml2sd.ui.load.IUml2SDLoader#getTitleString()
	 */
	public String getTitleString() {
		return TraceSDPlugin.getResourceString("STR_UML2SD_NODE_INTERACTION"); //$NON-NLS-1$
	}

	/**
	 * @see org.eclipse.hyades.uml2sd.trace.loaders.NoMessageInteractions#getEntryTime(org.eclipse.hyades.models.trace.TRCFullMethodInvocation)
	 */
	protected double getEntryTime(TRCFullMethodInvocation mi) {
		if (mi == mi.getProcess().getInvocations().get(0)) {
			return TraceInteractionUtils.getAbsoluteEntryTime(mi.getProcess());
		} else {
			return TraceInteractionUtils.getAbsoluteEntryTime(mi);
		}
	}
}

==> hyades.source_3.2.0_20041101_1032.zip: org/eclipse/hyades/uml2sd/trace/loaders/NodeInteractions.java <==
/**********************************************************************
 * Copyright (c) 2004 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.uml2sd.trace.loaders;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.hyades.models.hierarchy.TRCNode;
import org.eclipse.hyades.models.trace.TRCFullMethodInvocation;
import org.eclipse.hyades.uml2sd.trace.TraceSDPlugin;

/**
 * This class aims to populate a Node (host) Interaction UML2 Sequence Diagram.
 */
public class NodeInteractions extends BaseLifelineLoader {
	
	/**
	 * @see org.eclipse.hyades.uml2sd.trace.loaders.BaseTraceInteractions#getLifelineEObjectFromMethodInvocation(org.eclipse.hyades.models.trace.TRCFullMethodInvocation)
	 */
	public EObject getLifelineEObjectFromMethodInvocation(
			TRCFullMethodInvocation mi) {
		return mi.getProcess().getAgent().getAgentProxy().getProcessProxy().getNode(); // TRCNode
	}
	
	/**
	 * @see org.eclipse.hyades.uml2sd.trace.loaders.BaseTraceInteractions#getLifeLineCategory(org.eclipse.emf.ecore.EObject)
	 */
	public int getLifeLineCategory(EObject to) {
		return TraceInteractions.CATEGORY_NODE;
	}
	
	/**
	 * @see org.eclipse.hyades.uml2sd.trace.loaders.BaseTraceInteractions#getLifeLineTitle(org.eclipse.emf.ecore.EObject, boolean)
	 */
	public String getLifeLineTitle(EObject to, boolean long_) {
		TRCNode node = (TRCNode)to;
		return node.getName(); //$NON-NLS-1$
	}

	/**
	 * The host runtime id
	 */
	public String getLifeLineId(EObject eo) {
		return ((TRCNode)eo).getRuntimeId()+"#"+getLifeLineTitle(eo, true); //$NON-NLS-1$
	}
	
	/**
	 * This is the nose interactions, nothing else
	 */
	public String getFinalTitleString() {
		return TraceSDPlugin.getResourceString("STR_UML2SD_NODE_INTERACTION"); //$NON-NLS-1$
	}
	
}
